@@ -10,14 +10,14 @@ from trytond.transaction import Transaction
 from trytond.pool import Pool, PoolMeta
 
 from trytond.modules.account_product import MissingFunction
-from trytond.modules.product import price_digits
+from trytond.modules.product import price_digits, TemplateFunction
 
-__all__ = ['Category', 'Template', 'UpdateCostPriceAsk',
+__all__ = ['Category', 'Template', 'Product', 'UpdateCostPriceAsk',
     'UpdateCostPriceShowMove', 'UpdateCostPrice']
-__metaclass__ = PoolMeta
 
 
 class Category:
+    __metaclass__ = PoolMeta
     __name__ = 'product.category'
     account_stock = fields.Property(fields.Many2One('account.account',
             'Account Stock', domain=[
@@ -26,9 +26,10 @@ class Category:
                 ],
             states={
                 'invisible': (~Eval('context', {}).get('company')
-                    | Eval('account_parent')),
+                    | Eval('account_parent')
+                    | ~Eval('accounting', False)),
                 },
-            depends=['account_parent']))
+            depends=['account_parent', 'accounting']))
     account_stock_supplier = fields.Property(fields.Many2One('account.account',
             'Account Stock Supplier', domain=[
                 ('kind', '=', 'stock'),
@@ -36,9 +37,10 @@ class Category:
                 ],
             states={
                 'invisible': (~Eval('context', {}).get('company')
-                    | Eval('account_parent')),
+                    | Eval('account_parent')
+                    | ~Eval('accounting', False)),
                 },
-            depends=['account_parent']))
+            depends=['account_parent', 'accounting']))
     account_stock_customer = fields.Property(fields.Many2One('account.account',
             'Account Stock Customer', domain=[
                 ('kind', '=', 'stock'),
@@ -46,9 +48,10 @@ class Category:
                 ],
             states={
                 'invisible': (~Eval('context', {}).get('company')
-                    | Eval('account_parent')),
+                    | Eval('account_parent')
+                    | ~Eval('accounting', False)),
                 },
-            depends=['account_parent']))
+            depends=['account_parent', 'accounting']))
     account_stock_production = fields.Property(
         fields.Many2One('account.account',
             'Account Stock Production', domain=[
@@ -57,9 +60,10 @@ class Category:
                 ],
             states={
                 'invisible': (~Eval('context', {}).get('company')
-                    | Eval('account_parent')),
+                    | Eval('account_parent')
+                    | ~Eval('accounting', False)),
                 },
-            depends=['account_parent']))
+            depends=['account_parent', 'accounting']))
     account_stock_lost_found = fields.Property(fields.Many2One(
             'account.account', 'Account Stock Lost and Found', domain=[
                 ('kind', '=', 'stock'),
@@ -67,9 +71,10 @@ class Category:
                 ],
             states={
                 'invisible': (~Eval('context', {}).get('company')
-                    | Eval('account_parent')),
+                    | Eval('account_parent')
+                    | ~Eval('accounting', False)),
                 },
-            depends=['account_parent']))
+            depends=['account_parent', 'accounting']))
     account_stock_used = MissingFunction(fields.Many2One('account.account',
         'Account Stock Used'), 'missing_account', 'get_account')
     account_stock_supplier_used = MissingFunction(fields.Many2One(
@@ -87,6 +92,7 @@ class Category:
 
 
 class Template:
+    __metaclass__ = PoolMeta
     __name__ = 'product.template'
     account_stock = fields.Property(fields.Many2One('account.account',
             'Account Stock',
@@ -180,6 +186,27 @@ class Template:
                 })
 
 
+class Product:
+    __metaclass__ = PoolMeta
+    __name__ = 'product.product'
+    # Avoid raise of UserError from MissingFunction
+    account_stock_used = fields.Function(
+        fields.Many2One('account.account', 'Account Stock Used'),
+        'get_template')
+    account_stock_supplier_used = fields.Function(
+        fields.Many2One('account.account', 'Account Stock Supplier Used'),
+        'get_template')
+    account_stock_customer_used = fields.Function(
+        fields.Many2One('account.account', 'Account Stock Customer Used'),
+        'get_template')
+    account_stock_production_used = fields.Function(
+        fields.Many2One('account.account', 'Account Stock Production Used'),
+        'get_template')
+    account_stock_lost_found_used = fields.Function(
+        fields.Many2One('account.account', 'Account Stock Lost and Found'),
+        'get_template')
+
+
 class UpdateCostPriceAsk(ModelView):
     'Update Cost Price Ask'
     __name__ = 'product.update_cost_price.ask'
@@ -371,7 +398,7 @@ class UpdateCostPrice(Wizard):
         Product = pool.get('product.product')
         ProductTemplate = pool.get('product.template')
 
-        if hasattr(Product, 'cost_price'):
+        if not isinstance(Product.cost_price, TemplateFunction):
             write = partial(Product.write, [self.ask_price.product])
         else:
             if self.ask_price.template:
