@@ -147,14 +147,6 @@ class Move:
             lines=account_move_lines,
             )
 
-    @classmethod
-    def copy(cls, moves, default=None):
-        if default is None:
-            default = {}
-        default = default.copy()
-        default.setdefault('account_move', None)
-        return super(Move, cls).copy(moves, default=default)
-
     @classmethod
     @ModelView.button
     @Workflow.transition('done')
